function quad_run
% This file compiles the model and outputs the resonance frequencies in the
% vector 'modes', the mode shapes in the matrix 'phi', and the state space
% model in the state space variable 'mbquad'. It also plots the 6
% diagonal top mass to top mass transfer functions.
%
% The model state space variable is called mbquad. It has 24 outputs and 30
% inputs. The outputs go in the order of x,y,z,yaw,pitch,roll from top mass
% down to test mass. The inputs follow the same order except that the first
% 6 represent the DOFs of the seismic table. The state space variable
% follows the notation mbquad(output,input).
%
% Example: to view a transfer function for top mass x to top mass x type
% bode(mbquad(1,7))
% '1' represents the index of the top mass x position, '7' the top mass x
% force.
%
% The columns of phi represent the shapes of the modes, and are sorted in the
% same order as the modes vector, e.g. the 7th column is the mode shape of
% the seventh mode. The rows represent the motion of the masses in the same
% order as the outputs of mbquad, e.g. the top row represents top mass x,
% row 2 is top mass y, etc.
%
% One can get an idea of what 'type' (e.g. x vs pitch) of mode a mode is
% by examining the magnitude of the rows of a given column of phi. Perhaps
% more simply one can view the shape by entering the command
%
% figure,plot(abs(phi(:,mode_number))),grid on
%
% where mode_number is the index (or column) of the mode desired in order from lowest
% frequency to highest. The x axis is the row numbers of phi, the y axis
% the magnitude of the elements in the column. For example, if the plot has
% large peaks at only 5, 11, 17, and 23, then it is a 'pitch' mode.
%
% Brett Shapiro
% 11 August 2010

% close figures, and clear the command line
close all
clc

% compiles the model
ssmake4pv2eMB5f

% mode frequencies in units of Hz and mode shapes
[phi modes] = eig(-mbquad.a(25:48,1:24));
[modes ind] = sort(sqrt(diag(modes))/2/pi); % sorting and scaling the mode frequencies
phi = phi(:,ind); % sorting the mode shape matrix so the columns are in the same order as the modes
disp('Quad Resonant Frequencies in Hz')
disp(' ')
disp(num2str(modes)) % displaying the mode frequencies on the screen

% Plotting some top mass to top mass transfer functions
w = 2*pi*(0.1:0.001:10); % plotting frequency
    % X to X
    figure,bode(mbquad(1,7),w)
    title('Top Mass X to X Transfer Function')
    bform % give figure a nice format
    % Y to Y
    figure,bode(mbquad(2,8),w)
    title('Top Mass Y to Y Transfer Function')
    bform % give figure a nice format
    % Z to Z
    figure,bode(mbquad(3,9),w)
    title('Top Mass Z to Z Transfer Function')
    bform % give figure a nice format
    % YAW to YAW
    figure,bode(mbquad(4,10),w)
    title('Top Mass Yaw to Yaw Transfer Function')
    bform % give figure a nice format
    % PITCH to PITCH
    figure,bode(mbquad(5,11),w)
    title('Top Mass Pitch to Pitch Transfer Function')
    bform % give figure a nice format
    % ROLL to ROLL
    figure,bode(mbquad(6,12),w)
    title('Top Mass Roll to Roll Transfer Function')
    bform % give figure a nice format

    
% send useful info to command line workspace
assignin('base','mbquad',mbquad)
assignin('base','modes',modes)
assignin('base','phi',phi)
assignin('base','ind',ind)




function bform
% To format bode plots with default preferences from the command line
% 
% Frequency units are changed from rad/s to Hz.
% All fontsizes are increased to 20.
% The line widths are increased to 3.
% The grid is turned on.
% The figure is maximized.
%
% Brett Shapiro
% 4 November 2009

% Change units to Hz
h = gcr;
h.AxesGrid.XUnits = 'Hz';

% View grid
grid on

% % Maximize the figure
% maxfig

% Change the line widths
set(findobj(gcf,'type','line'),'linewidth',3);

% Change the font size
textsize = 20;
h.AxesGrid.AxesStyle.FontSize = textsize; % units
h.AxesGrid.TitleStyle.FontSize = textsize; % title
h.AxesGrid.XLabelStyle.FontSize = textsize; % x label
h.AxesGrid.YLabelStyle.FontSize = textsize; % x label

% Clearing the figure handle from the workspace
clear h